==> haskell-skylighting-format-context-0.1.0.2-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-4kqYv2hcB3G8nIUYU2HCwo
key:                  skylighting-format-context-0.1.0.2-4kqYv2hcB3G8nIUYU2HCwo
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  ba9f4250793f2c72b437b09c1b800b4d
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-4kqYv2hcB3G8nIUYU2HCwo
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.2-BJWyPBlMmxy4Iye3ZeyYVh text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-context-0.1.0.2-219-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-8DVAGdXtHXYAyKKbFqKgRJ
key:                  skylighting-format-context-0.1.0.2-8DVAGdXtHXYAyKKbFqKgRJ
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  f2b671c78c134475a45427441f5c3d03
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-8DVAGdXtHXYAyKKbFqKgRJ
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.2-3az6fNPJWgIHPFACMyT4kx text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
